==> nhc98_1.16.orig.tar.gz: nhc98-1.16/src/prelude/FFI/CError.p.c <==
#include "newmacros.h"
#include "runtime.h"

#define CT_v341	((void*)startLabel+120)
#define CT_v346	((void*)startLabel+248)
#define FN_NHC_46FFI_46getErrNo_35	((void*)startLabel+292)
#define CT_v349	((void*)startLabel+316)
#define F0_NHC_46FFI_46getErrNo_35	((void*)startLabel+324)
#define CT_v353	((void*)startLabel+404)
#define ST_v351	((void*)startLabel+440)
#define PP_NHC_46FFI_46getErrNo_35	((void*)startLabel+457)
#define PC_NHC_46FFI_46getErrNo_35	((void*)startLabel+457)
#define ST_v348	((void*)startLabel+457)
#define ST_v338	((void*)startLabel+476)
#define ST_v343	((void*)startLabel+496)
#define PS_v352	((void*)startLabel+520)
#define PS_v350	((void*)startLabel+532)
#define PS_v340	((void*)startLabel+544)
#define PS_v337	((void*)startLabel+556)
#define PS_v339	((void*)startLabel+568)
#define PS_v345	((void*)startLabel+580)
#define PS_v344	((void*)startLabel+592)
#define PS_v342	((void*)startLabel+604)
#define PS_v347	((void*)startLabel+616)
extern Node FN_Prelude_46Enum_46NHC_46DErrNo_46ErrNo_46toEnum[];
extern Node FN_Prelude_46ioError[];
void FR_NHC_46FFI_46getErrNo_35(void);
extern Node FN_NHC_46Internal_46_95mkIOok0[];
extern Node PM_NHC_46FFI[];
extern Node PC_NHC_46Internal_46_95mkIOok0[];
extern Node PM_NHC_46FFI[];
extern Node PM_NHC_46FFI[];
extern Node PC_Prelude_46IOError[];
extern Node PM_NHC_46FFI[];
extern Node PM_NHC_46FFI[];
extern Node PC_Prelude_46Enum_46NHC_46DErrNo_46ErrNo_46toEnum[];
extern Node PM_NHC_46FFI[];
extern Node PC_Prelude_46ioError[];
extern Node PM_NHC_46FFI[];
extern Node PM_NHC_46FFI[];
extern Node PM_NHC_46FFI[];

static Node startLabel[] = {
  bytes2word(0,0,4,0)
, bytes2word(3,1,2,2)
, bytes2word(1,3,0,4)
, useLabel(CT_v341)
,};
Node FN_NHC_46FFI_46mkIOError[] = {
  bytes2word(NEEDHEAP_I32,HEAP_CVAL_P1,7,HEAP_CVAL_N1)
, bytes2word(7,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_ARG,4,PUSH_HEAP,HEAP_CVAL_N1)
, bytes2word(12,HEAP_CVAL_N1,17,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_ARG_ARG,1)
, bytes2word(2,HEAP_ARG,3,HEAP_OFF_N1)
, bytes2word(14,RETURN,ENDCODE,0)
, bytes2word(0,0,0,0)
, 0
, useLabel(PS_v340)
, 0
, 0
, 0
, 0
, CONSTR(0,4,0)
, 0
, 0
, 0
, 0
, useLabel(PS_v339)
, 0
, 0
, 0
, 0
, 140001
, useLabel(ST_v338)
,	/* CT_v341: (byte 0) */
  HW(1,4)
, 0
,};
Node F0_NHC_46FFI_46mkIOError[] = {
  CAPTAG(useLabel(FN_NHC_46FFI_46mkIOError),4)
, useLabel(PS_v337)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_Prelude_46Enum_46NHC_46DErrNo_46ErrNo_46toEnum))
, bytes2word(0,0,4,0)
, bytes2word(3,1,2,2)
, bytes2word(1,3,0,4)
, useLabel(CT_v346)
,};
Node FN_NHC_46FFI_46throwIOError[] = {
  bytes2word(NEEDHEAP_I32,HEAP_CVAL_P1,7,HEAP_CVAL_N1)
, bytes2word(7,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_ARG_ARG,1,2,HEAP_ARG_ARG)
, bytes2word(3,4,PUSH_HEAP,HEAP_CVAL_P1)
, bytes2word(8,HEAP_CVAL_N1,12,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1,14)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, useLabel(PS_v345)
, 0
, 0
, 0
, 0
, useLabel(PS_v344)
, 0
, 0
, 0
, 0
, 170001
, useLabel(ST_v343)
,	/* CT_v346: (byte 0) */
  HW(2,4)
, 0
,};
Node F0_NHC_46FFI_46throwIOError[] = {
  CAPTAG(useLabel(FN_NHC_46FFI_46throwIOError),4)
, useLabel(PS_v342)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_NHC_46FFI_46mkIOError))
, VAPTAG(useLabel(FN_Prelude_46ioError))
, bytes2word(1,0,0,1)
, useLabel(CT_v349)
,	/* FN_NHC_46FFI_46getErrNo_35: (byte 0) */
  bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PRIMITIVE)
, useLabel(FR_NHC_46FFI_46getErrNo_35)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 110022
, useLabel(ST_v348)
,	/* CT_v349: (byte 0) */
  HW(0,1)
, 0
,	/* F0_NHC_46FFI_46getErrNo_35: (byte 0) */
  CAPTAG(useLabel(FN_NHC_46FFI_46getErrNo_35),1)
, useLabel(PS_v347)
, 0
, 0
, 0
, bytes2word(0,0,0,0)
, useLabel(CT_v353)
,};
Node FN_NHC_46FFI_46getErrNo[] = {
  bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_P1,7)
, bytes2word(HEAP_CVAL_N1,7,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_CVAL_P1,8,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 0
, useLabel(PS_v352)
, 0
, 0
, 0
, 0
, 110022
, useLabel(ST_v351)
,	/* CT_v353: (byte 0) */
  HW(2,0)
, 0
,};
Node CF_NHC_46FFI_46getErrNo[] = {
  VAPTAG(useLabel(FN_NHC_46FFI_46getErrNo))
, useLabel(PS_v350)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_NHC_46Internal_46_95mkIOok0))
, useLabel(F0_NHC_46FFI_46getErrNo_35)
,};
Node PP_NHC_46FFI_46getErrNo[] = {
 };
Node PC_NHC_46FFI_46getErrNo[] = {
 	/* ST_v351: (byte 0) */
  bytes2word(78,72,67,46)
, bytes2word(70,70,73,46)
, bytes2word(103,101,116,69)
, bytes2word(114,114,78,111)
,	/* PP_NHC_46FFI_46getErrNo_35: (byte 1) */
 	/* PC_NHC_46FFI_46getErrNo_35: (byte 1) */
 	/* ST_v348: (byte 1) */
  bytes2word(0,78,72,67)
, bytes2word(46,70,70,73)
, bytes2word(46,103,101,116)
, bytes2word(69,114,114,78)
, bytes2word(111,35,0,0)
,};
Node PP_NHC_46FFI_46mkIOError[] = {
 };
Node PC_NHC_46FFI_46mkIOError[] = {
 	/* ST_v338: (byte 0) */
  bytes2word(78,72,67,46)
, bytes2word(70,70,73,46)
, bytes2word(109,107,73,79)
, bytes2word(69,114,114,111)
, bytes2word(114,0,0,0)
,};
Node PP_NHC_46FFI_46throwIOError[] = {
 };
Node PC_NHC_46FFI_46throwIOError[] = {
 	/* ST_v343: (byte 0) */
  bytes2word(78,72,67,46)
, bytes2word(70,70,73,46)
, bytes2word(116,104,114,111)
, bytes2word(119,73,79,69)
, bytes2word(114,114,111,114)
, bytes2word(0,0,0,0)
,	/* PS_v352: (byte 0) */
  useLabel(PM_NHC_46FFI)
, useLabel(PP_NHC_46FFI_46getErrNo)
, useLabel(PC_NHC_46Internal_46_95mkIOok0)
,	/* PS_v350: (byte 0) */
  useLabel(PM_NHC_46FFI)
, useLabel(PP_NHC_46FFI_46getErrNo)
, useLabel(PC_NHC_46FFI_46getErrNo)
,	/* PS_v340: (byte 0) */
  useLabel(PM_NHC_46FFI)
, useLabel(PP_NHC_46FFI_46mkIOError)
, useLabel(PC_Prelude_46IOError)
,	/* PS_v337: (byte 0) */
  useLabel(PM_NHC_46FFI)
, useLabel(PP_NHC_46FFI_46mkIOError)
, useLabel(PC_NHC_46FFI_46mkIOError)
,	/* PS_v339: (byte 0) */
  useLabel(PM_NHC_46FFI)
, useLabel(PP_NHC_46FFI_46mkIOError)
, useLabel(PC_Prelude_46Enum_46NHC_46DErrNo_46ErrNo_46toEnum)
,	/* PS_v345: (byte 0) */
  useLabel(PM_NHC_46FFI)
, useLabel(PP_NHC_46FFI_46throwIOError)
, useLabel(PC_Prelude_46ioError)
,	/* PS_v344: (byte 0) */
  useLabel(PM_NHC_46FFI)
, useLabel(PP_NHC_46FFI_46throwIOError)
, useLabel(PC_NHC_46FFI_46mkIOError)
,	/* PS_v342: (byte 0) */
  useLabel(PM_NHC_46FFI)
, useLabel(PP_NHC_46FFI_46throwIOError)
, useLabel(PC_NHC_46FFI_46throwIOError)
,	/* PS_v347: (byte 0) */
  useLabel(PM_NHC_46FFI)
, useLabel(PP_NHC_46FFI_46getErrNo_35)
, useLabel(PC_NHC_46FFI_46getErrNo_35)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "getErrNo" NHC.FFI.getErrNo# 1 :: Prelude.() -> Prelude.Int */
extern HsInt getErrNo(void);
#ifdef PROFILE
static SInfo pf_getErrNo = {"NHC.FFI","NHC.FFI.getErrNo#","Prelude.Int"};
#endif
C_HEADER(FR_NHC_46FFI_46getErrNo_35) {
  NodePtr nodeptr;
  HsInt result;
  /* void arg1 */;

  result = getErrNo();

  nodeptr = nhc_mkInt(result);
  INIT_PROFINFO(nodeptr,&pf_getErrNo);
  C_RETURN(nodeptr);
}

==> nhc98_1.18.orig.tar.gz: nhc98-1.18/src/prelude/FFI/CError.p.c <==
#include "newmacros.h"
#include "runtime.h"

#define CT_v344	((void*)startLabel+120)
#define CT_v349	((void*)startLabel+248)
#define FN_NHC_46FFI_46getErrNo_35	((void*)startLabel+292)
#define CT_v352	((void*)startLabel+316)
#define F0_NHC_46FFI_46getErrNo_35	((void*)startLabel+324)
#define CT_v356	((void*)startLabel+404)
#define ST_v354	((void*)startLabel+440)
#define PP_NHC_46FFI_46getErrNo_35	((void*)startLabel+457)
#define PC_NHC_46FFI_46getErrNo_35	((void*)startLabel+457)
#define ST_v351	((void*)startLabel+457)
#define ST_v341	((void*)startLabel+476)
#define ST_v346	((void*)startLabel+496)
#define PS_v355	((void*)startLabel+520)
#define PS_v353	((void*)startLabel+532)
#define PS_v343	((void*)startLabel+544)
#define PS_v340	((void*)startLabel+556)
#define PS_v342	((void*)startLabel+568)
#define PS_v348	((void*)startLabel+580)
#define PS_v347	((void*)startLabel+592)
#define PS_v345	((void*)startLabel+604)
#define PS_v350	((void*)startLabel+616)
extern Node FN_Prelude_46Enum_46NHC_46DErrNo_46ErrNo_46toEnum[];
extern Node FN_Prelude_46ioError[];
void FR_NHC_46FFI_46getErrNo_35(void);
extern Node FN_NHC_46Internal_46_95mkIOok0[];
extern Node PM_NHC_46FFI[];
extern Node PC_NHC_46Internal_46_95mkIOok0[];
extern Node PC_Prelude_46IOError[];
extern Node PC_Prelude_46Enum_46NHC_46DErrNo_46ErrNo_46toEnum[];
extern Node PC_Prelude_46ioError[];

static Node startLabel[] = {
  bytes2word(0,0,4,0)
, bytes2word(3,1,2,2)
, bytes2word(1,3,0,4)
, useLabel(CT_v344)
,};
Node FN_NHC_46FFI_46mkIOError[] = {
  bytes2word(NEEDHEAP_I32,HEAP_CVAL_P1,7,HEAP_CVAL_N1)
, bytes2word(7,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_ARG,4,PUSH_HEAP,HEAP_CVAL_N1)
, bytes2word(12,HEAP_CVAL_N1,17,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_ARG_ARG,1)
, bytes2word(2,HEAP_ARG,3,HEAP_OFF_N1)
, bytes2word(14,RETURN,ENDCODE,0)
, bytes2word(0,0,0,0)
, 0
, useLabel(PS_v343)
, 0
, 0
, 0
, 0
, CONSTR(0,4,0)
, 0
, 0
, 0
, 0
, useLabel(PS_v342)
, 0
, 0
, 0
, 0
, 140001
, useLabel(ST_v341)
,	/* CT_v344: (byte 0) */
  HW(1,4)
, 0
,};
Node F0_NHC_46FFI_46mkIOError[] = {
  CAPTAG(useLabel(FN_NHC_46FFI_46mkIOError),4)
, useLabel(PS_v340)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_Prelude_46Enum_46NHC_46DErrNo_46ErrNo_46toEnum))
, bytes2word(0,0,4,0)
, bytes2word(3,1,2,2)
, bytes2word(1,3,0,4)
, useLabel(CT_v349)
,};
Node FN_NHC_46FFI_46throwIOError[] = {
  bytes2word(NEEDHEAP_I32,HEAP_CVAL_P1,7,HEAP_CVAL_N1)
, bytes2word(7,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_ARG_ARG,1,2,HEAP_ARG_ARG)
, bytes2word(3,4,PUSH_HEAP,HEAP_CVAL_P1)
, bytes2word(8,HEAP_CVAL_N1,12,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1,14)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, useLabel(PS_v348)
, 0
, 0
, 0
, 0
, useLabel(PS_v347)
, 0
, 0
, 0
, 0
, 170001
, useLabel(ST_v346)
,	/* CT_v349: (byte 0) */
  HW(2,4)
, 0
,};
Node F0_NHC_46FFI_46throwIOError[] = {
  CAPTAG(useLabel(FN_NHC_46FFI_46throwIOError),4)
, useLabel(PS_v345)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_NHC_46FFI_46mkIOError))
, VAPTAG(useLabel(FN_Prelude_46ioError))
, bytes2word(1,0,0,1)
, useLabel(CT_v352)
,	/* FN_NHC_46FFI_46getErrNo_35: (byte 0) */
  bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PRIMITIVE)
, useLabel(FR_NHC_46FFI_46getErrNo_35)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 110001
, useLabel(ST_v351)
,	/* CT_v352: (byte 0) */
  HW(0,1)
, 0
,	/* F0_NHC_46FFI_46getErrNo_35: (byte 0) */
  CAPTAG(useLabel(FN_NHC_46FFI_46getErrNo_35),1)
, useLabel(PS_v350)
, 0
, 0
, 0
, bytes2word(0,0,0,0)
, useLabel(CT_v356)
,};
Node FN_NHC_46FFI_46getErrNo[] = {
  bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_P1,7)
, bytes2word(HEAP_CVAL_N1,7,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_CVAL_P1,8,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 0
, useLabel(PS_v355)
, 0
, 0
, 0
, 0
, 110001
, useLabel(ST_v354)
,	/* CT_v356: (byte 0) */
  HW(2,0)
, 0
,};
Node CF_NHC_46FFI_46getErrNo[] = {
  VAPTAG(useLabel(FN_NHC_46FFI_46getErrNo))
, useLabel(PS_v353)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_NHC_46Internal_46_95mkIOok0))
, useLabel(F0_NHC_46FFI_46getErrNo_35)
,};
Node PP_NHC_46FFI_46getErrNo[] = {
 };
Node PC_NHC_46FFI_46getErrNo[] = {
 	/* ST_v354: (byte 0) */
  bytes2word(78,72,67,46)
, bytes2word(70,70,73,46)
, bytes2word(103,101,116,69)
, bytes2word(114,114,78,111)
,	/* PP_NHC_46FFI_46getErrNo_35: (byte 1) */
 	/* PC_NHC_46FFI_46getErrNo_35: (byte 1) */
 	/* ST_v351: (byte 1) */
  bytes2word(0,78,72,67)
, bytes2word(46,70,70,73)
, bytes2word(46,103,101,116)
, bytes2word(69,114,114,78)
, bytes2word(111,35,0,0)
,};
Node PP_NHC_46FFI_46mkIOError[] = {
 };
Node PC_NHC_46FFI_46mkIOError[] = {
 	/* ST_v341: (byte 0) */
  bytes2word(78,72,67,46)
, bytes2word(70,70,73,46)
, bytes2word(109,107,73,79)
, bytes2word(69,114,114,111)
, bytes2word(114,0,0,0)
,};
Node PP_NHC_46FFI_46throwIOError[] = {
 };
Node PC_NHC_46FFI_46throwIOError[] = {
 	/* ST_v346: (byte 0) */
  bytes2word(78,72,67,46)
, bytes2word(70,70,73,46)
, bytes2word(116,104,114,111)
, bytes2word(119,73,79,69)
, bytes2word(114,114,111,114)
, bytes2word(0,0,0,0)
,	/* PS_v355: (byte 0) */
  useLabel(PM_NHC_46FFI)
, useLabel(PP_NHC_46FFI_46getErrNo)
, useLabel(PC_NHC_46Internal_46_95mkIOok0)
,	/* PS_v353: (byte 0) */
  useLabel(PM_NHC_46FFI)
, useLabel(PP_NHC_46FFI_46getErrNo)
, useLabel(PC_NHC_46FFI_46getErrNo)
,	/* PS_v343: (byte 0) */
  useLabel(PM_NHC_46FFI)
, useLabel(PP_NHC_46FFI_46mkIOError)
, useLabel(PC_Prelude_46IOError)
,	/* PS_v340: (byte 0) */
  useLabel(PM_NHC_46FFI)
, useLabel(PP_NHC_46FFI_46mkIOError)
, useLabel(PC_NHC_46FFI_46mkIOError)
,	/* PS_v342: (byte 0) */
  useLabel(PM_NHC_46FFI)
, useLabel(PP_NHC_46FFI_46mkIOError)
, useLabel(PC_Prelude_46Enum_46NHC_46DErrNo_46ErrNo_46toEnum)
,	/* PS_v348: (byte 0) */
  useLabel(PM_NHC_46FFI)
, useLabel(PP_NHC_46FFI_46throwIOError)
, useLabel(PC_Prelude_46ioError)
,	/* PS_v347: (byte 0) */
  useLabel(PM_NHC_46FFI)
, useLabel(PP_NHC_46FFI_46throwIOError)
, useLabel(PC_NHC_46FFI_46mkIOError)
,	/* PS_v345: (byte 0) */
  useLabel(PM_NHC_46FFI)
, useLabel(PP_NHC_46FFI_46throwIOError)
, useLabel(PC_NHC_46FFI_46throwIOError)
,	/* PS_v350: (byte 0) */
  useLabel(PM_NHC_46FFI)
, useLabel(PP_NHC_46FFI_46getErrNo_35)
, useLabel(PC_NHC_46FFI_46getErrNo_35)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "getErrNo" NHC.FFI.getErrNo# 1 :: Prelude.() -> Prelude.Int */
extern HsInt getErrNo(void);
#ifdef PROFILE
static SInfo pf_NHC_46FFI_46getErrNo_35 = {"NHC.FFI","NHC.FFI.getErrNo#","Prelude.Int"};
#endif
C_HEADER(FR_NHC_46FFI_46getErrNo_35) {
  NodePtr nodeptr;
  HsInt result;
  /* void arg1 */;

  result = getErrNo();

  nodeptr = nhc_mkInt(result);
  INIT_PROFINFO(nodeptr,&pf_NHC_46FFI_46getErrNo_35);
  C_RETURN(nodeptr);
}
